#!/bin/sh

# Colours
Error="\033[1;31m"
Warning="\033[0;33m"
Progress="\033[1;32m"
Message="\033[1;34m"
Blank="\033[0m"

# Text Formatting
Bold="\033[1m"
Italic="\033[3m"
Underline="\033[4m"
Strikethrough="\033[9m"

SU_Check ()
{
echo ${Progress}"Checking for Superuser permissions..."${Blank}
mkdir $volume/Library/SU &> /dev/null
if [ -d "$volume/Library/SU" ]
then
echo ${Progress}"Superuser permissions check passed."${Blank}
rm -R $volume/Library/SU
else
echo ${Error}"Superuser permissions check failed."${Blank}
echo ${Message}"Please run this script with Superuser permissions."${Blank}
exit
fi
}

SIP_Check ()
{
echo ${Progress}"Checking for System Integrity Protection status..."${Blank}
mkdir $volume/System/Library/SIP &> /dev/null
if [ -d "$volume/System/Library/SIP" ]
then
echo ${Progress}"System Integrity Protection status check passed."${Blank}
rm -R $volume/System/Library/SIP
else
echo ${Error}"System Integrity Protection status check failed."${Blank}
echo ${Message}"Please run this script with System Integrity Protection disabled."${Blank}
exit
fi
}

Ask_Package_Folder ()
{
echo ${Message}"What folder would you like to use?"${Blank}
echo ${Italic}${Message}"Please respond with the path of a folder containing the package."${Blank}
read package_folder
}

Ask_Package ()
{
echo ${Message}"What package would you like to use?"${Blank}
echo ${Italic}${Message}"Please respond with the name of the package."${Blank}
read package
}

Ask_Volume ()
{
echo ${Message}"What volume would you like to install on?"${Blank}
echo ${Italic}${Message}"Please respond with a volume path."${Blank}
read volume
}

Install ()
{
echo ${Progress}"Expanding package..."${Blank}
pkgutil --expand-full "$package_folder"/"$package".pkg "$package_folder"/"$package"
echo ${Progress}"Package expanded."${Blank}

echo ${Progress}"Installing update..."${Blank}
cp -rf "$package_folder"/"$package"/Payload/ "$volume"/ &> /dev/null
echo ${Progress}"Update installed."${Blank}
}

Ask_Restart ()
{
echo ${Message}"Would you like to restart your machine now?"${Blank}
echo ${Italic}${Message}"Please respond with \"Yes\" or \"No\"."${Blank}
read restart

if [[ $restart == "Yes" ]]
then
Restart_Now
fi
if [[ $restart == "No" ]]
then
Restart_Later
fi
}

Restart_Now ()
{
echo ${Message}"Your machine will restart soon."${Blank}
echo ${Italic}${Message}"Thank you for using my patch."${Blank}
reboot
}

Restart_Later ()
{
echo ${Message}"Please restart your machine soon."${Blank}
echo ${Italic}${Message}"Thank you for using my patch."${Blank}
exit
}

SU_Check
SIP_Check
Ask_Package_Folder
Ask_Package
Ask_Volume
Install
Ask_Restart